<img align="left" height="120" src="docs/assets/logo.png">

# KraK - Tools for Computational Geomechanics
[![yetisir](https://circleci.com/gh/yetisir/krak.svg?style=svg)](https://app.circleci.com/pipelines/github/yetisir/krak) [![Coverage Status](https://coveralls.io/repos/github/yetisir/krake/badge.svg?branch=master)](https://coveralls.io/github/yetisir/krak?branch=master) [![Maintainability](https://api.codeclimate.com/v1/badges/78f17dc4e5d8ebfad02e/maintainability)](https://codeclimate.com/github/yetisir/krak/maintainability) [![Documentation Status](https://readthedocs.org/projects/krak/badge/?version=latest)](https://krak.readthedocs.io/en/latest/?badge=latest)
  

KraK is a Python library to help build and run computational geomechnical models. This is still a work in progress and features may be incomplete and/or undocumented.

KraK relies on much of the hard work by the [PyVista](https://docs.pyvista.org/) and [PyMesh](https://pymesh.readthedocs.io/en/latest/) teams

## Installation

The latest release of KraK can be installed with [pip](https://pip.pypa.io/en/stable/). PyMesh is not available through pypi and must be [installed](https://pymesh.readthedocs.io/en/latest/installation.html) seperately.

A Dockerfile is provided to help build a working environment for KraK. More details to come.

Additionally - a frontend for KraK is available [here](https://github.com/yetisir/krak-server)


```bash
python -m pip install krak
```

## Documentation

The latest documentation is hosted [here](https://krak.readthedocs.io/en/latest/?badge=latest)


## License
dNote is licensed under the [GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/)

